"""General-use classes to interact with the CodeStarNotifications service through CloudFormation.

See Also:
    `AWS developer guide for CodeStarNotifications
    <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import codestarnotifications as _raw

# noinspection PyUnresolvedReferences
from .._raw.codestarnotifications import *



"""General-use classes to interact with the QLDB service through CloudFormation.

See Also:
    `AWS developer guide for QLDB
    <https://docs.aws.amazon.com/qldb/latest/developerguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import qldb as _raw

# noinspection PyUnresolvedReferences
from .._raw.qldb import *



"""General-use classes to interact with the AccessAnalyzer service through CloudFormation.

See Also:
    `AWS developer guide for AccessAnalyzer
    <https://aws.amazon.com/iam/features/analyze-access/>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import accessanalyzer as _raw

# noinspection PyUnresolvedReferences
from .._raw.accessanalyzer import *



"""General-use classes to interact with the CodeStar service through CloudFormation.

See Also:
    `AWS developer guide for CodeStar
    <https://docs.aws.amazon.com/codestar/latest/userguide/welcome.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import codestar as _raw

# noinspection PyUnresolvedReferences
from .._raw.codestar import *



"""General-use classes to interact with the SecurityHub service through CloudFormation.

See Also:
    `AWS developer guide for SecurityHub
    <https://docs.aws.amazon.com/securityhub/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import securityhub as _raw

# noinspection PyUnresolvedReferences
from .._raw.securityhub import *



"""Raw representations of every data type in the AWS CodeStarNotifications service.

See Also:
    `AWS developer guide for CodeStarNotifications
    <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = ["NotificationRule", "NotificationRuleProperties"]


@attrs(**ATTRSCONFIG)
class NotificationRuleProperties(ResourceProperties):
    DetailType = attrib(default=None)
    EventTypeIds = attrib(default=None)
    Name = attrib(default=None)
    Resource = attrib(default=None)
    Status = attrib(default=None)
    Tags = attrib(default=None)
    Targets = attrib(default=None)


@attrs(**ATTRSCONFIG)
class NotificationRule(Resource):
    """A Notification Rule for CodeStarNotifications.

    See Also:
        `AWS Cloud Formation documentation for NotificationRule
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html>`_
    """

    RESOURCE_TYPE = "AWS::CodeStarNotifications::NotificationRule"

    Properties: NotificationRuleProperties = attrib(
        factory=NotificationRuleProperties,
        converter=create_object_converter(NotificationRuleProperties),
    )



"""Raw representations of every data type in the AWS AccessAnalyzer service.

See Also:
    `AWS developer guide for AccessAnalyzer
    <https://aws.amazon.com/iam/features/analyze-access/>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = ["Analyzer", "AnalyzerProperties"]


@attrs(**ATTRSCONFIG)
class AnalyzerProperties(ResourceProperties):
    AnalyzerName = attrib(default=None)
    ArchiveRules = attrib(default=None)
    Tags = attrib(default=None)
    Type = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Analyzer(Resource):
    """A Analyzer for AccessAnalyzer.

    See Also:
        `AWS Cloud Formation documentation for Analyzer
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-accessanalyzer-analyzer.html>`_
    """

    RESOURCE_TYPE = "AWS::AccessAnalyzer::Analyzer"

    Properties: AnalyzerProperties = attrib(
        factory=AnalyzerProperties,
        converter=create_object_converter(AnalyzerProperties),
    )



"""Raw representations of every data type in the AWS MediaLive service.

See Also:
    `AWS developer guide for MediaLive
    <https://docs.aws.amazon.com/pinpoint/latest/userguide/welcome.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "Channel",
    "ChannelProperties",
    "Input",
    "InputProperties",
    "InputSecurityGroup",
    "InputSecurityGroupProperties",
]


@attrs(**ATTRSCONFIG)
class ChannelProperties(ResourceProperties):
    ChannelClass = attrib(default=None)
    Destinations = attrib(default=None)
    EncoderSettings = attrib(default=None)
    InputAttachments = attrib(default=None)
    InputSpecification = attrib(default=None)
    LogLevel = attrib(default=None)
    Name = attrib(default=None)
    RoleArn = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Channel(Resource):
    """A Channel for MediaLive.

    See Also:
        `AWS Cloud Formation documentation for Channel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-medialive-channel.html>`_
    """

    RESOURCE_TYPE = "AWS::MediaLive::Channel"

    Properties: ChannelProperties = attrib(
        factory=ChannelProperties, converter=create_object_converter(ChannelProperties)
    )


@attrs(**ATTRSCONFIG)
class InputProperties(ResourceProperties):
    Destinations = attrib(default=None)
    InputSecurityGroups = attrib(default=None)
    MediaConnectFlows = attrib(default=None)
    Name = attrib(default=None)
    RoleArn = attrib(default=None)
    Sources = attrib(default=None)
    Tags = attrib(default=None)
    Type = attrib(default=None)
    Vpc = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Input(Resource):
    """A Input for MediaLive.

    See Also:
        `AWS Cloud Formation documentation for Input
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-medialive-input.html>`_
    """

    RESOURCE_TYPE = "AWS::MediaLive::Input"

    Properties: InputProperties = attrib(
        factory=InputProperties, converter=create_object_converter(InputProperties)
    )


@attrs(**ATTRSCONFIG)
class InputSecurityGroupProperties(ResourceProperties):
    Tags = attrib(default=None)
    WhitelistRules = attrib(default=None)


@attrs(**ATTRSCONFIG)
class InputSecurityGroup(Resource):
    """A Input Security Group for MediaLive.

    See Also:
        `AWS Cloud Formation documentation for InputSecurityGroup
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-medialive-inputsecuritygroup.html>`_
    """

    RESOURCE_TYPE = "AWS::MediaLive::InputSecurityGroup"

    Properties: InputSecurityGroupProperties = attrib(
        factory=InputSecurityGroupProperties,
        converter=create_object_converter(InputSecurityGroupProperties),
    )



"""Raw representations of every data type in the AWS EventSchemas service.

See Also:
    `AWS developer guide for EventSchemas
    <https://docs.aws.amazon.com/eventbridge/latest/userguide/index.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "Discoverer",
    "DiscovererProperties",
    "Registry",
    "RegistryProperties",
    "Schema",
    "SchemaProperties",
]


@attrs(**ATTRSCONFIG)
class DiscovererProperties(ResourceProperties):
    Description = attrib(default=None)
    SourceArn = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Discoverer(Resource):
    """A Discoverer for EventSchemas.

    See Also:
        `AWS Cloud Formation documentation for Discoverer
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html>`_
    """

    RESOURCE_TYPE = "AWS::EventSchemas::Discoverer"

    Properties: DiscovererProperties = attrib(
        factory=DiscovererProperties,
        converter=create_object_converter(DiscovererProperties),
    )


@attrs(**ATTRSCONFIG)
class RegistryProperties(ResourceProperties):
    Description = attrib(default=None)
    RegistryName = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Registry(Resource):
    """A Registry for EventSchemas.

    See Also:
        `AWS Cloud Formation documentation for Registry
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html>`_
    """

    RESOURCE_TYPE = "AWS::EventSchemas::Registry"

    Properties: RegistryProperties = attrib(
        factory=RegistryProperties,
        converter=create_object_converter(RegistryProperties),
    )


@attrs(**ATTRSCONFIG)
class SchemaProperties(ResourceProperties):
    Content = attrib(default=None)
    Description = attrib(default=None)
    RegistryName = attrib(default=None)
    SchemaName = attrib(default=None)
    Tags = attrib(default=None)
    Type = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Schema(Resource):
    """A Schema for EventSchemas.

    See Also:
        `AWS Cloud Formation documentation for Schema
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html>`_
    """

    RESOURCE_TYPE = "AWS::EventSchemas::Schema"

    Properties: SchemaProperties = attrib(
        factory=SchemaProperties, converter=create_object_converter(SchemaProperties)
    )



"""General-use classes to interact with the LakeFormation service through CloudFormation.

See Also:
    `AWS developer guide for LakeFormation
    <https://docs.aws.amazon.com/lake-formation/latest/dg/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import lakeformation as _raw

# noinspection PyUnresolvedReferences
from .._raw.lakeformation import *



"""General-use classes to interact with the MediaConvert service through CloudFormation.

See Also:
    `AWS developer guide for MediaConvert
    <http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import mediaconvert as _raw

# noinspection PyUnresolvedReferences
from .._raw.mediaconvert import *



"""General-use classes to interact with the IoTEvents service through CloudFormation.

See Also:
    `AWS developer guide for IoTEvents
    <https://docs.aws.amazon.com/iotevents/latest/developerguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import iotevents as _raw

# noinspection PyUnresolvedReferences
from .._raw.iotevents import *



"""General-use classes to interact with the EventSchemas service through CloudFormation.

See Also:
    `AWS developer guide for EventSchemas
    <https://docs.aws.amazon.com/eventbridge/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import eventschemas as _raw

# noinspection PyUnresolvedReferences
from .._raw.eventschemas import *



"""General-use classes to interact with the Lambda service through CloudFormation.

See Also:
    `AWS developer guide for Lambda
    <https://docs.aws.amazon.com/lambda/latest/dg/welcome.html>`_
"""

import inspect
import sys
import warnings
from typing import Callable

import inflection

# noinspection PyUnresolvedReferences
from .._raw import lambda_ as _raw

# noinspection PyUnresolvedReferences
from .._raw.lambda_ import *


class Function(_raw.Function):
    __slots__ = []

    @classmethod
    def create_from_python_function(
        cls, handler: Callable, Role, Description=None, Runtime=None
    ) -> "Function":
        """Factory function to create a Function with inlined code from a Python function."""
        # Extract and format source code
        handler_sig = inspect.signature(handler)
        if len(handler_sig.parameters) > 2:
            raise ValueError("Lambda handler takes too many parameters")

        param_names = list(handler_sig.parameters.keys())
        if len(param_names) >= 1 and param_names[0] not in ("e", "event"):
            warnings.warn(
                UserWarning(
                    "First handler parameter has an unusual name: '{}'".format(
                        param_names[0]
                    )
                )
            )
        if len(param_names) >= 2 and param_names[1] not in ("c", "context"):
            warnings.warn(
                UserWarning(
                    "Second handler parameter has an unusual name: '{}'".format(
                        param_names[1]
                    )
                )
            )

        source = inspect.getsource(handler)

        # Automatically generate description. We pluck out just the first
        # paragraph of the docstring, formatted into a single line
        desc = Description
        if not desc:
            if handler.__doc__:
                docstring_lines = []
                for line in handler.__doc__.split("\n"):
                    line = line.strip()

                    # Use empty lines to detect paragraph breaks, and drop
                    # everything after the first paragraph
                    if not line:
                        if not docstring_lines:
                            # ...but just ignoire leading empty lines
                            continue
                        break

                    docstring_lines.append(line.strip())
                desc = " ".join(docstring_lines)
            else:
                desc = inflection.humanize(handler.__name__) + "."

        # Create a basic Function resource with only the compulsory properties
        return cls(
            Properties=FunctionProperties(
                Code=dict(ZipFile=source),
                Description=desc,
                Handler="index.{}".format(handler.__name__),
                Role=Role,
                Runtime=Runtime or get_lambda_runtime_for_this_process(),
            )
        )


#: Lambda Runtimes for Python that we know about.
#: See `the definitive list in the AWS documentation
#: <https://docs.aws.amazon.com/lambda/latest/dg/python-programming-model.html>`_
_KNOWN_LAMBDA_RUNTIMES = {(2, 7): "python2.7", (3, 6): "python3.6", (3, 7): "python3.7"}


def get_lambda_runtime_for_this_process() -> str:
    """Determine the best Lambda runtime for the current Python process."""
    # The basic premise is to use exact matching if possible, upgrade if
    # necessary, and don't downgrade

    (major, minor, _, _, _) = sys.version_info

    try:
        return _KNOWN_LAMBDA_RUNTIMES[(major, minor)]
    except KeyError:
        pass

    # Maybe this is an old Python v3
    if major == 3 and minor < 6:
        return _KNOWN_LAMBDA_RUNTIMES[(3, 6)]

    # Maybe this is an old Python v2
    if major == 2 and minor < 7:
        return _KNOWN_LAMBDA_RUNTIMES[(2, 7)]

    raise ValueError(
        "Python version '{}' cannot be supported by AWS Lambda".format(sys.version)
    )



"""General-use classes to interact with the Backup service through CloudFormation.

See Also:
    `AWS developer guide for Backup
    <https://docs.aws.amazon.com/aws-backup/latest/devguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import backup as _raw

# noinspection PyUnresolvedReferences
from .._raw.backup import *



"""Raw representations of every data type in the AWS MediaConvert service.

See Also:
    `AWS developer guide for MediaConvert
    <http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "JobTemplate",
    "JobTemplateProperties",
    "Preset",
    "PresetProperties",
    "Queue",
    "QueueProperties",
]


@attrs(**ATTRSCONFIG)
class JobTemplateProperties(ResourceProperties):
    AccelerationSettings = attrib(default=None)
    Category = attrib(default=None)
    Description = attrib(default=None)
    Name = attrib(default=None)
    Priority = attrib(default=None)
    Queue = attrib(default=None)
    SettingsJson = attrib(default=None)
    StatusUpdateInterval = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class JobTemplate(Resource):
    """A Job Template for MediaConvert.

    See Also:
        `AWS Cloud Formation documentation for JobTemplate
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html>`_
    """

    RESOURCE_TYPE = "AWS::MediaConvert::JobTemplate"

    Properties: JobTemplateProperties = attrib(
        factory=JobTemplateProperties,
        converter=create_object_converter(JobTemplateProperties),
    )


@attrs(**ATTRSCONFIG)
class PresetProperties(ResourceProperties):
    Category = attrib(default=None)
    Description = attrib(default=None)
    Name = attrib(default=None)
    SettingsJson = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Preset(Resource):
    """A Preset for MediaConvert.

    See Also:
        `AWS Cloud Formation documentation for Preset
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html>`_
    """

    RESOURCE_TYPE = "AWS::MediaConvert::Preset"

    Properties: PresetProperties = attrib(
        factory=PresetProperties, converter=create_object_converter(PresetProperties)
    )


@attrs(**ATTRSCONFIG)
class QueueProperties(ResourceProperties):
    Description = attrib(default=None)
    Name = attrib(default=None)
    PricingPlan = attrib(default=None)
    Status = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Queue(Resource):
    """A Queue for MediaConvert.

    See Also:
        `AWS Cloud Formation documentation for Queue
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html>`_
    """

    RESOURCE_TYPE = "AWS::MediaConvert::Queue"

    Properties: QueueProperties = attrib(
        factory=QueueProperties, converter=create_object_converter(QueueProperties)
    )



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['flyingcircus',
 'flyingcircus._raw',
 'flyingcircus.recipes',
 'flyingcircus.service']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=5.1.1,<5.2.0', 'attrs>=18.2.0,<19.0.0', 'inflection>=0.3.1,<0.4.0']

setup_kwargs = {
    'name': 'flying-circus',
    'version': '0.7.3',
    'description': 'A tool for describing AWS infrastructure as code',
    'long_description': '[![PyPI release](https://img.shields.io/pypi/v/flying-circus.svg)](https://pypi.python.org/pypi/flying-circus)\n[![Python versions](https://img.shields.io/pypi/pyversions/flying-circus.svg)](https://pypi.python.org/pypi/flying-circus)\n[![Build Status](https://dev.azure.com/garyd203/flying-circus/_apis/build/status/garyd203.flying-circus?branchName=master)](https://dev.azure.com/garyd203/flying-circus/_build/latest?definitionId=1&branchName=master)\n[![Documentation Status](https://readthedocs.org/projects/flying-circus/badge/?version=latest)](http://flying-circus.readthedocs.io/en/latest/?badge=latest)\n[![Downloads](https://img.shields.io/pypi/dm/flying-circus.svg)](https://pypi.python.org/pypi/flying-circus)\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)\n\n# flying-circus\n\nFlying Circus is a tool for describing AWS infrastructure as code (using\nPython). It uses the same data structures as the AWS Cloud Formation service,\nexcept described as Python objects instead of the usual YAML. The Python\nprogram generates a YAML template, which is passed across to Cloud Formation\nin the usual manner.\n\nIt is a bit unusual to use a full programming language to describe\ninfrastructure, instead of a static configuration file like many of us are\nused to (whether or not we also utilise a templating tool).\nWe hope that the Flying Circus library can empower DevOps folk by unlocking\nsome of the techniques that are available for software code, like named\nvariables and techniques to structure code independently of the output format,\nlibraries to allow code re-use with versioning, automated refactoring tools\nand so on.\n\nYou can learn how to use Flying Circus yourself by reading the\n[documentation](https://flying-circus.readthedocs.io/)\n\n# Installation\n\nInstall Flying Circus through the Python packaging system:\n\n```bash\npip install flying-circus\n```\n\nMany people also use the Amazon Web Services command line tools to deploy\ntheir CloudFormation stacks. If you want this, a good way to install an\nup-to-date version is also with `pip`:\n\n```bash\n# Optional\npip install awscli\n```\n\n# Example\n\nHere is a simple example of how you can use Flying Circus to describe some EC2\ninstances and deploy them using the AWS CloudFormation service.\n\nFirst, create a python script (called `my_ec2_stack.py` in this case) to\ndescribe your infrastructure. Any valid Python can be used to create the\nFlying Circus objects, along with any valid CloudFormation properties and\nattributes.\n\nThis example is intentionally simplistic - it just creates two EC2 instances\nwith varying configuration, and outputs the internal IP for one. However, it\ndoes hint at some of the more complex and powerful usage patterns.\n\n```python\nimport os\n\nfrom flyingcircus.core import Stack, Output\nfrom flyingcircus.intrinsic_function import GetAtt\nfrom flyingcircus.service.ec2 import *\n\n\ndef create_ec2_instance(name, instance_type="t2.micro"):\n    instance = Instance(Properties=InstanceProperties(\n        ImageId="ami-942dd1f6",\n        InstanceType=instance_type,\n        Monitoring=False,\n    ))\n    instance.name = name\n    return instance\n\n\nif __name__ == "__main__":\n    stack = Stack()\n\n    stack.Resources["WebServer"] = create_ec2_instance("webserver")\n    stack.Resources["DatabaseServer"] = dbserver = create_ec2_instance("dbserver", "t2.medium")\n    dbserver.DeletionPolicy = "Retain"\n\n    stack.Outputs["DatabaseServerIp"] = Output(\n        Description=f"Internal IP address for the database server",\n        Value=GetAtt(dbserver, "PrivateIp"),\n    )\n\n    stack.tag(application="api-service", environment="test", owner=os.environ.get("USER"))\n\n    print(stack.export("yaml"))\n```\n\nNow generate CloudFormation YAML from your Python script. Note that the result\nwill *always* be valid well-formatted YAML, and internal checks mean that it\nis also difficult to generate invalid CloudFormation.\n\nFinally, use the AWS command line tools to create/update a stack and it\'s\nassociated resources.\n\n```bash\npython my_ec2_stack.py > my_ec2_stack.yaml\naws cloudformation deploy --stack-name demo-flying-circus-ec2 --template-file my_ec2_stack.yaml\n```\n\nYou could do these steps in your Continuous Integration server ;-)\n\n# Is/Is Not\n\nThere\'s a lot of tools for managing Infrastructure as Code, often with subtle\ndifferences and passionate advocates. A quick discussion of our scope may\nhelp you understand where Flying Circus fits into this ecosystem, and whether it can\nhelp you. This is presented in the simple "Is/Is Not" format.\n\n## Flying Circus Is...\n\n* ...a Pythonic DSL for writing fully featured Python code\n* ...for Amazon Web Services infrastructure\n* ...built on top of AWS [Cloud Formation templates](http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-guide.html)\n* ...a generator that always produces valid, consistent, human-readable, good-practice YAML\n\n## Flying Circus Is Not...\n\n* ...YAML or JSON. It\'s Python.\n* ...a tool to make it easier to write YAML or JSON. You write Python, and YAML is an output format.\n* ...a DSL with a completely new syntax. You use normal Python syntax with all\n  of it\'s features and nothing changed.\n* ...a templating language, like Jinja2.\n* ...a template management tool, like Ansible.\n* ...an independent implementation of infrastructure management, like AWS\n  Cloud Formation stacks, or Terraform.\n* ...a cloud-agnostic abstraction layer.\n* ...multi-cloud - although it could become this in the future.\n  The current implementation is focused on representing AWS infrastructure\n  using the CloudFormation data model. Other cloud providers have similar\n  native data models, so it is feasible that we could re-use the concepts and\n  tooling to support Google Cloud Platform, etc.\n* ...a tool for interacting with the Cloud Formation service. There\n  are other tools that can do this for you (such as boto3 or the AWS CLI,\n  for starters)\n* ...a validation tool - although it could become this in the future, and\n  already has elements of validation as a by-product of presenting a helpful\n  interface to users.\n\n# Sounds Great, Can I Use It?\n\nSure, of course you can. The [documentation will get you started](https://flying-circus.readthedocs.io/en/latest/getting_started.html).\n\nFlying Circus is currently in **Beta**. This means it is expected\nto work for the supported AWS services, and is in use by real customers.\nHowever, the details of the interface and implementation are still being\nvalidated and may change drastically.\n\n# How Do I Help?\n\nJust use it!\n',
    'author': 'Gary Donovan',
    'author_email': 'gazza@gazza.id.au',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/garyd203/flying-circus',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



"""Raw representations of every data type in the AWS Amplify service.

See Also:
    `AWS developer guide for Amplify
    <https://docs.aws.amazon.com/amplify/latest/userguide/getting-started.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "App",
    "AppProperties",
    "Branch",
    "BranchProperties",
    "Domain",
    "DomainProperties",
]


@attrs(**ATTRSCONFIG)
class AppProperties(ResourceProperties):
    AccessToken = attrib(default=None)
    AutoBranchCreationConfig = attrib(default=None)
    BasicAuthConfig = attrib(default=None)
    BuildSpec = attrib(default=None)
    CustomRules = attrib(default=None)
    Description = attrib(default=None)
    EnvironmentVariables = attrib(default=None)
    IAMServiceRole = attrib(default=None)
    Name = attrib(default=None)
    OauthToken = attrib(default=None)
    Repository = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class App(Resource):
    """A App for Amplify.

    See Also:
        `AWS Cloud Formation documentation for App
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amplify-app.html>`_
    """

    RESOURCE_TYPE = "AWS::Amplify::App"

    Properties: AppProperties = attrib(
        factory=AppProperties, converter=create_object_converter(AppProperties)
    )


@attrs(**ATTRSCONFIG)
class BranchProperties(ResourceProperties):
    AppId = attrib(default=None)
    BasicAuthConfig = attrib(default=None)
    BranchName = attrib(default=None)
    BuildSpec = attrib(default=None)
    Description = attrib(default=None)
    EnableAutoBuild = attrib(default=None)
    EnablePullRequestPreview = attrib(default=None)
    EnvironmentVariables = attrib(default=None)
    PullRequestEnvironmentName = attrib(default=None)
    Stage = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Branch(Resource):
    """A Branch for Amplify.

    See Also:
        `AWS Cloud Formation documentation for Branch
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amplify-branch.html>`_
    """

    RESOURCE_TYPE = "AWS::Amplify::Branch"

    Properties: BranchProperties = attrib(
        factory=BranchProperties, converter=create_object_converter(BranchProperties)
    )


@attrs(**ATTRSCONFIG)
class DomainProperties(ResourceProperties):
    AppId = attrib(default=None)
    DomainName = attrib(default=None)
    SubDomainSettings = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Domain(Resource):
    """A Domain for Amplify.

    See Also:
        `AWS Cloud Formation documentation for Domain
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amplify-domain.html>`_
    """

    RESOURCE_TYPE = "AWS::Amplify::Domain"

    Properties: DomainProperties = attrib(
        factory=DomainProperties, converter=create_object_converter(DomainProperties)
    )



"""Raw representations of every data type in the AWS WAFv2 service.

See Also:
    `AWS developer guide for WAFv2
    <https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "IPSet",
    "IPSetProperties",
    "RegexPatternSet",
    "RegexPatternSetProperties",
    "RuleGroup",
    "RuleGroupProperties",
    "WebACL",
    "WebACLProperties",
]


@attrs(**ATTRSCONFIG)
class IPSetProperties(ResourceProperties):
    Addresses = attrib(default=None)
    Description = attrib(default=None)
    IPAddressVersion = attrib(default=None)
    Name = attrib(default=None)
    Scope = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class IPSet(Resource):
    """A Ip Set for WAFv2.

    See Also:
        `AWS Cloud Formation documentation for IPSet
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-wafv2-ipset.html>`_
    """

    RESOURCE_TYPE = "AWS::WAFv2::IPSet"

    Properties: IPSetProperties = attrib(
        factory=IPSetProperties, converter=create_object_converter(IPSetProperties)
    )


@attrs(**ATTRSCONFIG)
class RegexPatternSetProperties(ResourceProperties):
    Description = attrib(default=None)
    Name = attrib(default=None)
    RegularExpressionList = attrib(default=None)
    Scope = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class RegexPatternSet(Resource):
    """A Regex Pattern Set for WAFv2.

    See Also:
        `AWS Cloud Formation documentation for RegexPatternSet
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-wafv2-regexpatternset.html>`_
    """

    RESOURCE_TYPE = "AWS::WAFv2::RegexPatternSet"

    Properties: RegexPatternSetProperties = attrib(
        factory=RegexPatternSetProperties,
        converter=create_object_converter(RegexPatternSetProperties),
    )


@attrs(**ATTRSCONFIG)
class RuleGroupProperties(ResourceProperties):
    Capacity = attrib(default=None)
    Description = attrib(default=None)
    Name = attrib(default=None)
    Rules = attrib(default=None)
    Scope = attrib(default=None)
    Tags = attrib(default=None)
    VisibilityConfig = attrib(default=None)


@attrs(**ATTRSCONFIG)
class RuleGroup(Resource):
    """A Rule Group for WAFv2.

    See Also:
        `AWS Cloud Formation documentation for RuleGroup
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-wafv2-rulegroup.html>`_
    """

    RESOURCE_TYPE = "AWS::WAFv2::RuleGroup"

    Properties: RuleGroupProperties = attrib(
        factory=RuleGroupProperties,
        converter=create_object_converter(RuleGroupProperties),
    )


@attrs(**ATTRSCONFIG)
class WebACLProperties(ResourceProperties):
    DefaultAction = attrib(default=None)
    Description = attrib(default=None)
    Name = attrib(default=None)
    Rules = attrib(default=None)
    Scope = attrib(default=None)
    Tags = attrib(default=None)
    VisibilityConfig = attrib(default=None)


@attrs(**ATTRSCONFIG)
class WebACL(Resource):
    """A Web Acl for WAFv2.

    See Also:
        `AWS Cloud Formation documentation for WebACL
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-wafv2-webacl.html>`_
    """

    RESOURCE_TYPE = "AWS::WAFv2::WebACL"

    Properties: WebACLProperties = attrib(
        factory=WebACLProperties, converter=create_object_converter(WebACLProperties)
    )
